var abbApp = angular.module('abb', ['ngCookies', 'localization', 'ng', 'picker', 'ngUpload' ]);

abbApp.config(function($routeProvider) {
	$routeProvider.when('/channels', {
		templateUrl : 'partials/channel-data.html',
		controller : ChannelDataCtrl
	}).when('/configuration', {
		templateUrl : 'partials/configuration.html',
		controller : ConfigurationCtrl
	}).when('/status', {
		templateUrl : 'partials/instrument-status.html',
		controller : InstrumentStatusCtrl
	}).when('/logs', {
		templateUrl : 'partials/logs.html',
		controller : LogsCtrl
	}).when('/multi', {
		templateUrl : 'partials/multi-instrument.html',
		controller : MultiInstrumentCtrl
	}).when('/operatormessage', {
		templateUrl : 'partials/operator-message.html',
		controller : OperatorMessageCtrl
	}).when('/home', {
		templateUrl : 'partials/home.html',
		controller : HomeCtrl
	}).when('/remoteOperation', {
		templateUrl : 'js/remoteOperation/remoteOperation.html',
		controller : RemoteOperationController
	}).otherwise({
		redirectTo : '/home'
	});
});

abbApp.config(function($httpProvider) {
	function errorInterceptor($q, $log, $location) {
		function success(response) {
			return response;
		}
		function error(response) {
		    if (response.config != null &&
		        response.config.url.indexOf('cmd=operator_connect') == -1 &&
		        response.config.url.indexOf('cmd=operator_lbuttondown_event') == -1 &&
                response.config.url.indexOf('cmd=operator_activeView') == -1 &&
                [415, 500].indexOf(response.status) > -1) {
				$('#error-dialog').modal().on('hidden', function() {
					window.location = '.';
				});
			}
			return $q.reject(response);
		}
		return function(promise) {
			return promise.then(success, error);
		};
	}
	$httpProvider.responseInterceptors.push(errorInterceptor);
});



abbApp.run(function($http, $rootScope, $window, $cookieStore, $location, $timeout, localize, $cookies) {
	$rootScope.showErrorModal = function() {
		$('#error-dialog').modal().on('hidden', function() {
			window.location = '.';
		});
	};
	
	$rootScope.validateJSONresponse = function(headers) {
		if(headers("Content-Type") != null && headers("Content-Type") != "application/json"){
			$rootScope.showErrorModal();
			return false;
		} 
		return true;
	};

	var authz = $cookieStore.get("authz");
	 if(authz != null) {
			$http.defaults.headers.common['Authorization'] = authz;
	 }
	 
	 $http.get("abb_isapi.dll?cmd=device_info").success(function(data, status, headers) {
		 if($rootScope.validateJSONresponse(headers)){
				  $rootScope.deviceInfo = data;
				  if(data.defaultLang != undefined){
					  localize.setLanguage(data.defaultLang);
				  }
				  else{
					  localize.setLanguage($window.navigator.language);
				  }
			  }
		  }).error(function(data) {
			  localize.setLanguage($window.navigator.language);
	 });
	 
	  $rootScope.setLanguage = function(code) {
		  localize.setLanguage(code);
	  };
	  
	  
	  $rootScope.logout = function() {
		  $rootScope.role = null;
		  $rootScope.username = null;
		  //var partialWithoutHash = window.location.hash.replace("#", "");
		  $cookieStore.remove('authz');
		  $cookieStore.remove('username');
		  $cookieStore.remove('role');
		  if(window.location.hash == "#/configuration" || window.location.hash == "#/operatormessage") {
			  $location.path("/");
		  } else {
			  location.reload(true);
		  }
	  };

	  
});

abbApp.directive("navbar", function() {
	return {
  restrict: "E",
  replace: true,
  transclude: true,
  templateUrl: "partials/navBar.html",
  compile: function(scope, element, attrs) { 
    var li, liElements, links, index, length;
    liElements = $(element).find("#navigation-tabs li");  
    for (index = 0, length = liElements.length; index < length; index++) {
      li = liElements[index];
      links = $(li).find("a"); 
      if (links[0].id === attrs.currentTab) $(li).addClass("active");
    }
    
  }
};
});

abbApp.directive("headerbar", function($cookieStore) {
	return {
	  restrict: "E",
	  replace: true,
	  transclude: true,
	  templateUrl: "partials/header.html",
	  link: function(rootScope, element, attrs) {
		  rootScope.username = $cookieStore.get('username');
		  rootScope.role = $cookieStore.get('role');
	  }
	};
});


